# eric7.PipInterface

Package implementing the various pip dialogs and data.

### Modules

Pip | Package implementing the pip GUI logic.
PipDialog | Module implementing a dialog showing the output of a pip command.
PipFileSelectionDialog | Module implementing a dialog to enter a file to be processed.
PipFreezeDialog | Module implementing a dialog to generate a requirements file.
PipLicensesDialog | Module implementing a dialog to show the licenses of an environment.
PipPackageDetailsDialog | Module implementing a dialog to show details about a package.
PipPackagesInputDialog | Module implementing a dialog to enter package specifications.
PipPackagesWidget | Module implementing the pip packages management widget.
PipPackagesWindow | Module implementing the standalone pip packages management window.
PipVulnerabilityChecker | Module implementing a Python package vulnerability checker.
piplicenses | pip-licenses